@@ -6,6 +6,7 @@
 //! - clean up expired snapshots
 //!
 
+#![cfg(target_os = "linux")]
 #![deny(warnings)]
 #![deny(missing_docs)]
 
@@ -99,7 +100,7 @@ impl BtmCfg {
         }
     }
 
-    /// Get snapshot list in desc order.
+    /// Get snapshot list in 'DESC' order.
     #[inline(always)]
     pub fn get_sorted_snapshots(&self) -> Result<Vec<u64>> {
         match self.mode {
